@@ -63,6 +63,8 @@ py_midgard_register_classes(PyObject *d)
 	py_midgard_reflection_property_register_class(d, &PyGObject_Type);
 	py_midgard_replicator_register_class(d, &PyGObject_Type);
 	py_midgard_dbus_register_class(d, &PyGObject_Type);
+	py_midgard_transaction_register_class(d, &PyGObject_Type);
+	py_midgard_storage_register_class(d, &PyGObject_Type);
 
 	py_midgard_object_class_register_class(d, &PyGObject_Type);
 
@@ -74,6 +76,10 @@ py_midgard_register_classes(PyObject *d)
 	PyObject *mmodule = PyImport_ImportModule("_midgard");
 	PyTypeObject *qbot = (PyTypeObject *)PyObject_GetAttrString(mmodule, "query_builder");
 	py_midgard_collector_register_class(d, &qbot);
+
+	py_midgard_key_config_context_register_class(d, &PyGObject_Type);
+	PyTypeObject *kccot = (PyTypeObject *)PyObject_GetAttrString(mmodule, "key_config_context");
+	py_midgard_key_config_file_context_register_class(d, &kccot);
 }
 
 static void
@@ -102,6 +108,32 @@ py_midgard_register_schema_classes(PyObject *d)
 	py_midgard_object_register_class(d, &PyGObject_Type);
 }
 
+static void
+py_midgard_register_view_classes(PyObject *d)
+{
+	PyObject *module;
+		
+	if ((module = PyImport_ImportModule("gobject")) != NULL) {
+		
+		_MPyGObject_Type = (PyTypeObject *)PyObject_GetAttrString(module, "GObject");
+		
+		if (_MPyGObject_Type == NULL) {
+			
+			PyErr_SetString(PyExc_ImportError,
+					"cannot import name GObject from gobject");
+			return ;
+		}
+	
+	} else {
+		
+		PyErr_SetString(PyExc_ImportError, "could not import gobject");
+		
+		return ;
+	}
+
+	py_midgard_view_register_class(d, &PyGObject_Type);
+}
+
 void
 py_midgard_register_db_classes(PyObject *d)
 {
@@ -133,7 +165,7 @@ static const PyMethodDef py_midgard_functions[] = {
 	{ NULL, NULL, 0, NULL }
 };
 
-static py_midgard_define_constants(PyObject *m)
+static void py_midgard_define_constants(PyObject *m)
 {
 	/* Register properties' midgard types */
 	PyModule_AddIntConstant(m, "TYPE_NONE", MGD_TYPE_NONE);
@@ -146,20 +178,16 @@ static py_midgard_define_constants(PyObject *m)
 	PyModule_AddIntConstant(m, "TYPE_LONGTEXT", MGD_TYPE_LONGTEXT);
 	PyModule_AddIntConstant(m, "TYPE_GUID", MGD_TYPE_GUID);
 
-	/* Register midgard_user and auth constants */
-	PyModule_AddIntConstant(m, "USER_HASH_LEGACY", MIDGARD_USER_HASH_LEGACY);
-	PyModule_AddIntConstant(m, "USER_HASH_LEGACY_PLAIN", MIDGARD_USER_HASH_LEGACY_PLAIN);
-	PyModule_AddIntConstant(m, "USER_HASH_CRYPT", MIDGARD_USER_HASH_CRYPT);
-	PyModule_AddIntConstant(m, "USER_HASH_MD5", MIDGARD_USER_HASH_MD5);
-	PyModule_AddIntConstant(m, "USER_HASH_PLAIN", MIDGARD_USER_HASH_PLAIN);
-	PyModule_AddIntConstant(m, "USER_HASH_SHA1", MIDGARD_USER_HASH_SHA1);
-	PyModule_AddIntConstant(m, "USER_HASH_PAM", MIDGARD_USER_HASH_PAM);
+	/* Register midgard_user types */
+	PyModule_AddIntConstant(m, "USER_TYPE_NONE", MIDGARD_USER_TYPE_NONE);
+	PyModule_AddIntConstant(m, "USER_TYPE_USER", MIDGARD_USER_TYPE_USER);
+	PyModule_AddIntConstant(m, "USER_TYPE_ADMIN", MIDGARD_USER_TYPE_ADMIN);
 
 	/* Register errcode constants */
 	PyModule_AddIntConstant(m, "ERR_OK", MGD_ERR_OK);
         PyModule_AddIntConstant(m, "ERR_ERROR", MGD_ERR_ERROR);
         PyModule_AddIntConstant(m, "ERR_ACCESS_DENIED", MGD_ERR_ACCESS_DENIED);
-        PyModule_AddIntConstant(m, "ERR_SITEGROUP_VIOLATION", MGD_ERR_SITEGROUP_VIOLATION);
+	PyModule_AddIntConstant(m, "ERR_NO_METADATA", MGD_ERR_NO_METADATA);
         PyModule_AddIntConstant(m, "ERR_NOT_OBJECT", MGD_ERR_NOT_OBJECT);
         PyModule_AddIntConstant(m, "ERR_NOT_EXISTS", MGD_ERR_NOT_EXISTS);
         PyModule_AddIntConstant(m, "ERR_INVALID_NAME", MGD_ERR_INVALID_NAME);
@@ -188,7 +216,7 @@ static py_midgard_define_constants(PyObject *m)
 DL_EXPORT(void)
 init_midgard(void)
 {
-	PyObject *m, *d, *tuple, *o, *sm, *dm;
+	PyObject *m, *d, *tuple, *sm, *dm, *vm;
 
 	/* initialise pygobject */
 	init_pygobject_check(2, 12, 0);
@@ -211,8 +239,7 @@ init_midgard(void)
 		/* FIXME, we need to unref it when module is unloaded! */ 
 		midgard_global_schema = g_object_new(MIDGARD_TYPE_SCHEMA, NULL);
 		midgard_schema_init((MidgardSchema *) midgard_global_schema, NULL);
-		midgard_schema_read_dir((MidgardSchema *) midgard_global_schema, 
-				MIDGARD_LSCHEMA_DIR);
+		midgard_schema_read_dir((MidgardSchema *) midgard_global_schema, NULL);
 	}
 
 	m = Py_InitModule("_midgard", (PyMethodDef*)py_midgard_functions);
@@ -248,6 +275,14 @@ init_midgard(void)
 	PyModule_AddObject(m, "mgdschema", sm);
 	py_midgard_register_schema_classes(sd);
 	
+	/* Mgdschema view module */
+	vm = Py_InitModule("__view__", NULL);
+	if(!vm) 
+		g_warning("Failed to initialize mgdschema view module");
+	PyObject *vd = PyModule_GetDict(vm);
+	PyModule_AddObject(m, "view", vm);
+	py_midgard_register_view_classes(vd);
+
 	/* Globals */
 
 	/* Set null connection "superglobal" */
@@ -418,8 +453,11 @@ void py_midgard_gvalue_from_pyobject(GValue *gvalue, const PyObject *pyvalue)
 
 GParameter *_py_midgard_parameters_from_args(PyObject *args, guint *n_params)
 {
-	if(!args)
+	if(!args) {
+
+		*n_params = 0;
 		return NULL;
+	}
 
 	gint i = 0;
 	GParameter *params = NULL;
@@ -429,7 +467,11 @@ GParameter *_py_midgard_parameters_from_args(PyObject *args, guint *n_params)
 	if(*n_params < 1)
 		return NULL;
 
+#if PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION == 4
+	int pos = 0;
+#elif PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION > 4
 	Py_ssize_t pos = 0;
+#endif
 	PyObject *key;
 	PyObject *value;
 
@@ -449,7 +491,8 @@ GParameter *_py_midgard_parameters_from_args(PyObject *args, guint *n_params)
 	return params;
 }
 
-gchar *_py_midgard_format_string(const gchar *msg , ...)    
+gchar *
+_py_midgard_format_string (const gchar *msg , ...)    
 {
 	va_list args;
 	va_start(args, msg);
@@ -458,3 +501,14 @@ gchar *_py_midgard_format_string(const gchar *msg , ...)
 	
 	return _msg;
 }
+
+void 
+_py_midgard_gobject_destructor (PyObject *self)
+{	
+	PyGObject *pygobj = (PyGObject *) self;
+	if (pygobj->obj && G_IS_OBJECT (pygobj->obj))
+		g_object_unref (pygobj->obj);
+
+	PyObject_GC_Del (self);
+	//_Py_ForgetReference (self);
+}
