@@ -99,7 +99,7 @@ PyTypeObject G_GNUC_INTERNAL Pymidgard_metadata_Type = {
     sizeof(PyGObject),          /* tp_basicsize */
     0,                                 /* tp_itemsize */
     /* methods */
-    (destructor)0,        /* tp_dealloc */
+    (destructor)_py_midgard_gobject_destructor,        /* tp_dealloc */
     (printfunc)0,                      /* tp_print */
     (getattrfunc)0,       /* tp_getattr */
     (setattrfunc)0,       /* tp_setattr */
@@ -145,8 +145,6 @@ void py_midgard_metadata_register_class(
 			MIDGARD_TYPE_METADATA, 
 			&Pymidgard_metadata_Type, 
 			Py_BuildValue("(O)", pygobject_type));
-
-	pyg_set_object_has_new_constructor(MIDGARD_TYPE_DBOBJECT);
 }
 
 /* MgdSchema classes */
@@ -154,7 +152,7 @@ static int __schema_object_construct(PyGObject *self, PyObject *args, PyObject *
 {
 	PyObject *pyval = NULL;
 	int id;
-	long lid;
+        // long lid;
 	const gchar *guid;
 	if(!PyArg_ParseTuple(args, "|O", &pyval))
 		return -1;
@@ -308,7 +306,8 @@ pymidgard_object_is_in_parent_tree(PyGObject *self, PyObject *args)
 {
 	MGDOBJECT_DEBUG("is_in_parent_tree");
 	guint root_id, id;
-	if(!PyArg_ParseTuple(args, "ii", root_id, id))
+
+	if(!PyArg_ParseTuple(args, "ii", &root_id, &id))
 		return NULL;
 
 	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
@@ -324,7 +323,8 @@ pymidgard_object_is_in_tree(PyGObject *self, PyObject *args)
 {
 	MGDOBJECT_DEBUG("is_in_tree");
 	guint root_id, id;
-	if(!PyArg_ParseTuple(args, "ii", root_id, id))
+
+	if (!PyArg_ParseTuple(args, "ii", &root_id, &id))
 		return NULL;
 
 	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
@@ -440,36 +440,6 @@ pymidgard_object_list_children(PyGObject *self, PyObject *args)
 	return list;
 }
 
-static PyObject *
-pymidgard_object_get_languages(PyGObject *self, PyObject *args)
-{
-	MGDOBJECT_DEBUG("get_languages");
-	if(!PyArg_ParseTuple(args, ""))
-		return NULL;
-
-	guint i = 0;
-	guint n_objects;
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
-	GObject **objects = midgard_object_get_languages(mobj, &n_objects);
-
-	if(objects == NULL) {
-		
-		PyObject *list = PyTuple_New(i);
-		return list;
-	}
-
-	PyObject *list = PyTuple_New(n_objects);
-
-	if(!objects) 
-		return list;
-
-	OBJECTS2LIST(objects, list);
-
-	g_free(objects);
-
-	return list;
-}
-
 static PyObject *
 pymidgard_object_get_by_path(PyGObject *self, PyObject *args)
 {
@@ -596,7 +566,6 @@ static PyMethodDef pymidgard_object_methods[] = {
 	{ "list", (PyCFunction)pymidgard_object_list, METH_VARARGS },
 	{ "list_children", (PyCFunction)pymidgard_object_list_children, METH_VARARGS },
 	{ "has_dependents", (PyCFunction)pymidgard_object_has_dependents, METH_NOARGS },
-	{ "get_languages", (PyCFunction)pymidgard_object_get_languages, METH_VARARGS },
 	{ "get_by_path", (PyCFunction)pymidgard_object_get_by_path, METH_VARARGS },
 	{ "get_parameter", (PyCFunction)pymidgard_object_get_parameter, METH_VARARGS },
 	{ "set_parameter", (PyCFunction)pymidgard_object_set_parameter, METH_VARARGS },
@@ -633,7 +602,7 @@ _py_midgard_get_object_attribute(PyObject *self, PyObject *attr)
 	GObjectClass *klass = G_OBJECT_GET_CLASS(object);
 	GParamSpec *pspec;
 	const gchar *attr_name = PyString_AsString(attr);
-	PyTypeObject *tp = self->ob_type;
+        // PyTypeObject *tp = self->ob_type;
 
 	pspec = g_object_class_find_property(klass, attr_name);
 
@@ -719,11 +688,23 @@ PyTypeObject *__new_object_struct(const gchar *typename)
 	PyTypeObject *ot = g_new0(PyTypeObject, 1);
 	ot->ob_refcnt = 1;
 	ot->ob_type = NULL;
-	ot->tp_name = g_strdup(typename);
+
+	/* Remove midgard_ prefix from class name as those are already used in midgard namespace */
+	if (g_str_has_prefix (typename, "midgard_")) {
+		
+		gchar **spltd = g_strsplit (typename, "_", 2);		
+		ot->tp_name = g_strdup(spltd[1]);
+		g_strfreev (spltd);
+
+	} else {
+
+		ot->tp_name = g_strdup (typename);
+	}
+
 	ot->ob_size = 0;
 	ot->tp_basicsize = sizeof(PyGObject);
 	ot->tp_itemsize = 0;
-	ot->tp_dealloc = 0;
+	ot->tp_dealloc = _py_midgard_gobject_destructor;
 	ot->tp_print = 0;
 	ot->tp_getattr = 0;
 	ot->tp_setattr = 0;
@@ -795,7 +776,7 @@ void py_midgard_object_register_class(
 				/* FIXME, What is a static bases in this case? */
 				Py_BuildValue("(O)", pygobject_type)); 
 
-		pyg_set_object_has_new_constructor(all_types[i]);
+		/* pyg_set_object_has_new_constructor(all_types[i]); */
 
 		g_hash_table_insert(_pytype_hash, 
 				(gpointer*)typename, (gpointer *)ot);
